==> JVPC-0.93.zip: JVPC-0.93/jvpc/ShipFrame.java <==
// File: ShipFrame.java

package jvpc.jvpc;

import java.awt.*;
import java.awt.event.*;
import kero.util.*;
import kero.awt.*;
import jvpc.vga.*;

/**
 * Presents a <CODE>Ship</code> in a <CODE>Frame</code>. Does not have
 * <CODE>Container</code> functionality (explicitely dropped).
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     22 V 1999
 * @version   18 III 2001
 */
public class ShipFrame
    extends MyFrame
    implements VGAPlanets, ShipListener,
	       ItemListener, ActionListener, KeyListener
{
    // fields with information
    Game game;
    Ship ship; // ship from a turn (not a result)

    // fields for UI
    static ShipFrame lastopened;
    JVPC applet;

    // General fields
    Label id;
    Button prev, next;
    InputField name, fcode;
    TextField fcfield;
    Label owner, crew,damage;
    Label hull, engine, torp, beam;
    // Mission stuff (quite a lot, to be PHost compatible)
    Panel missionPanel, targetPanel;      // when editable, use this Panel
    InputChoice missionchoice;            // stuff this all..
    IntInput inttarget,towtarget;     // ..into missionpanel
    InputChoice enemy;
    // Other stuff
    InputChoice warp;
    Panel positions; // current and new position
    Label position;
    IntInput newx,newy;
    Panel buttonPanel;
    Button cargo, planet;

    private void setupMissionChoice() {
	missionchoice = new InputChoice("Mission:");
	int m = 0;
	Mission mi;
	String str = game.getMission(m).getName();
	while (str != null) {
	    missionchoice.addSelection(str);
	    m++;
	    mi=game.getMission(m);
	    if (mi != null) str = mi.getName(); else str = null;
	}
	PConfig pconfig = ship.getUniverse().getConfig();
	if (pconfig != null) {
	    // add separator?
	    for (m=pconfig.extMissionsStartAt(); m<=game.getMissVecSize(); m++){
		mi = game.getMission(m);
		if (mi!=null) {
		    str = mi.getName();
		    missionchoice.addSelection(str);
		}
	    }
	}
	missionchoice.addActionListener(this);
    }

    public void itemStateChanged(ItemEvent ie) {
	String str = (String)ie.getItem();
	Object source = ie.getSource();
	if (source instanceof Choice) {
	    //if (source==missionchoice) setMission(game.getMission(str));
	}
    }

    public void actionPerformed(ActionEvent ae) {
	super.actionPerformed(ae);
	// String str = (String)ae.getActionCommand();
	// Object source = ae.getSource();
    }

    public void setShipIntTarget() {
	ship.setIntTarget(inttarget.getInt());
    }

    public void setShipTowTarget() {
	ship.setTowTarget(towtarget.getInt());
    }

    protected String oldName = "";

    public void setMission(Mission mission) {
	String newName = mission.getName();
	missionchoice.setSelection(newName);
	boolean sameMission = oldName.equals(newName);
	oldName = newName;
	if (sameMission) return;

	targetPanel.removeAll();
	addInputTo(missionPanel,missionchoice, KeyEvent.VK_M, "setShipMission");
	// set intercept label+textfield
	String hint = mission.getIntHint();
	if (hint != null) {
	    inttarget.setLabel(hint);
	    inttarget.setInt(ship.getIntTarget());
	    addNumberInputTo(targetPanel, inttarget, KeyEvent.VK_I,
			     "setShipIntTarget");
	}
	// set tow label+textfield
	hint = mission.getTowHint();
	if (hint != null) {
	    towtarget.setLabel(hint);
	    towtarget.setInt(ship.getTowTarget());
	    addNumberInputTo(targetPanel, towtarget, KeyEvent.VK_T,
			     "setShipTowTarget");
	}

	// work-around for kaffe: can not handle empty GridLayout-Containers
	if (targetPanel.getComponentCount() == 0) targetPanel.add(new Label());

	missionPanel.validate();
    }

    public void setShipMission() {
	Mission mission = game.getMission(missionchoice.getSelection());
	ship.setMission(mission.getId());
	//setMission(mission);
    }

    public void setWarp(String warp) {
	String stripped = warp.substring(1,2);
	ship.setWarp(Integer.parseInt(stripped));
    }

    public void setShipEnemy() {
	ship.setEnemy(enemy.getIndex());
    }

    public ShipFrame(Ship sh, JVPC ja) {
	ship = sh;
	game = ship.getUniverse().getGame();
	applet = ja;

	ship.getUniverse().addShipListener(this);

	owner = new Label();
	setLayout(new GridLayout(0,1));

	FlowLayout flowNoVgap = new FlowLayout();
	flowNoVgap.setVgap(0); // v-gap, not vga-p :-)

    Panel f = new Panel(new GridLayout(1, 0));
    id = new Label("Ship 999"); f.add(id);
    prev = new Button("prev");
    addButtonTo(f, prev, KeyEvent.VK_Z, "prevShip");
    next = new Button("neXt");
    addButtonTo(f, next, KeyEvent.VK_X, "nextShip");
    add(f);

	add(hull = new Label());
	add(engine = new Label());
	add(beam = new Label());
	add(torp = new Label());

	name = new InputField("Name:", "");
	// name.setTextFont(new Font("Courier",12,Font.PLAIN));
	addInputField(name, KeyEvent.VK_N, "setShipName");

	fcode = new InputField("Friendly code:", "");
	addInputField(fcode, KeyEvent.VK_F, "setShipFC");

	inttarget = new IntInput("Intercept:", 500, 2, 0);
	towtarget = new IntInput("Tow Ship:", 500, 2, 0);
	setupMissionChoice();

	missionPanel = new Panel(new BorderLayout());
	targetPanel = new Panel(new GridLayout(1, 0));
	missionPanel.add(targetPanel, "East");
	enemy = new InputChoice("primary Enemy:");
	// enemychoice.addItemListener(this);
	for (int i=0; i<=races; i++) enemy.addSelection(game.getLongRace(i));
	warp = new InputChoice("Warp:");
	for (int i=0; i<=maxWarp; i++) warp.addSelection(" "+i+" ");
	addInput(warp, KeyEvent.VK_W, "setShipWarp");
	positions = new Panel(flowNoVgap);
	position = new Label();
	positions.add(position);
	newx = new IntInput("dest. X:", 1234, 1, 0);
	newx.addActionListener(this);
	addNumberInputTo(positions, newx, KeyEvent.VK_X, "setDestX");
	newy = new IntInput("Y:", 1243, 1, 0);
	newy.addActionListener(this);
	addNumberInputTo(positions, newy, KeyEvent.VK_Y, "setDestY");

	// group items
	crew = new Label();
	damage = new Label();
	add(damage);
	add(crew);
	add(owner);
	add(fcode);
	add(missionPanel);
	addInput(enemy, KeyEvent.VK_E, "setShipEnemy");
	add(positions);
	add(warp);

	buttonPanel = new Panel(new GridLayout(1, 0));
	cargo = new Button("carGo");
	addButtonTo(buttonPanel, cargo, KeyEvent.VK_G, "viewCargoFrame");
	planet = new Button("Planet");
	addButtonTo(buttonPanel, planet, KeyEvent.VK_P, "viewPlanetFrame");
	add(buttonPanel);

	setShip(sh);
	pack();
	show();
	name.requestFocus();
    }

    public void setShip(Ship sh) {
	ship = sh;

	Universe u = ship.getUniverse();
	setTitle("S"+ship.getId()+", "+u.getTurnString());
	id.setText("Ship "+ship.getId());
	owner.setText("Owner: "+ship.getOwner());
	hull.setText(""+ship.getHull().getName());
	engine.setText(""+ship.getHull().getEngines()+" "+ship.getEngine().getName());
	int beamcount = ship.getBeamCount();
	if (beamcount > 0) {
	    beam.setText(""+beamcount+" "+ship.getBeam().getName());
	} else {
	    beam.setText("(no beams)");
	}
	int launchcount = ship.getLaunchCount();
	if (launchcount > 0) {
	    torp.setText(""+launchcount+" "+ship.getTorpedo().getName());
	} else {
	    torp.setText("(no torpedoes)");
	}

	name.setText(ship.getName());
	fcode.setText(ship.getFC());

	setMission(game.getMission(ship.getMission()));
	enemy.setSelection(game.getLongRace(ship.getEnemy()));
	warp.setSelection(ship.getWarp());
	position.setText("Pos: ("+ship.getX()+","+ship.getY()+")");
	newx.setInt(ship.getX()+ship.getDX());
	newy.setInt(ship.getY()+ship.getDY());
	int crewcount = ship.getCrew();
	if (crewcount>0) { // UNKNOWN???
	    int hullcrewcount = ship.getHull().getCrew();
	    if (crewcount < hullcrewcount) {
		crew.setText("Crew: "+crewcount+" (should be "+hullcrewcount+")");
	    } else {
		crew.setText("Crew: "+crewcount);
	    }
	}
	damage.setText("Damage: "+ship.getDamage());

	Planet p = ship.getLocation().getPlanet();
	if (p != null) {
	    buttonPanel.add(planet);
	} else {
	    buttonPanel.remove(planet);
	}
	buttonPanel.validate();
    }


    // KeyListener methods

    public void keyPressed(KeyEvent ke) {
	super.keyPressed(ke);
	boolean altheld = (ke.getModifiers() & KeyEvent.ALT_MASK) != 0;
	boolean ctrlheld = (ke.getModifiers() & KeyEvent.CTRL_MASK) != 0;
	boolean shiftheld = (ke.getModifiers() & KeyEvent.SHIFT_MASK) != 0;

	int keycode = ke.getKeyCode();
	switch (keycode) {
	case KeyEvent.VK_EQUALS:
	    if (!altheld && !ctrlheld) break;
	default:
	    // ignore
	    break;
	}
    }

    public void keyReleased(KeyEvent ke) {
	super.keyReleased(ke);
    }

    public void keyTyped(KeyEvent ke) {
	super.keyTyped(ke);
    }

  public void nextShip() {
    nextShip(true);
  }
  
  public void nextShip(boolean visitAlly) {
    int newid = ship.getId() + 1;
    if (newid > ships) newid = 1;
    while (newid != ship.getId()) {
      Ship newship = ship.getUniverse().getShip(newid);
      if ((newship != null) && newship.isOurShip()) {
	if ((newship.getOwner() == ship.getOwner()) || visitAlly) {
	  break;
	}
      }
      newid++;
      if (newid > ships) newid = 1;
    }
    setShip(ship.getUniverse().getShip(newid));
  }

  public void prevShip() {
    prevShip(true);
  }

  public void prevShip(boolean visitAlly) {
    int newid = ship.getId() - 1;
    if (newid == 0) newid = ships;
    while (newid != ship.getId()) {
      Ship newship = ship.getUniverse().getShip(newid);
      if ((newship != null) && newship.isOurShip()) {
	if ((newship.getOwner() == ship.getOwner()) || visitAlly) {
	  break;
	}
      }
      newid--;
      if (newid == 0) newid = ships;
    }
    setShip(ship.getUniverse().getShip(newid));
  }

    // ShipFrame overridden methods

    public void report(String warning) {
	game.report(warning);
	System.err.println(warning);
    }

    public void shipChanged(ShipEvent se) {
	if (se.getId() == ship.getId()) setShip(ship);
    }


    // methods for setting all ship fields

    public void setShipName() {
	ship.setName(((InputField)name).getText());
    }

    public void setShipFC() {
	ship.setFC(((InputField)fcode).getText());
    }

    public void setDestX() {
	ship.setDX(newx.getInt() - ship.getX());
    }

    public void setDestY() {
	ship.setDY(newy.getInt() - ship.getY());
    }

    public void setShipWarp() {
	ship.setWarp(warp.getIndex());
    }

    public void viewCargoFrame() {
	Location location = ship.getLocation();
	applet.viewCargoFrame(location);
    }

    public void viewPlanetFrame() {
	Planet p = ship.getLocation().getPlanet();
	applet.viewPlanet(p);	
    }
}

==> JVPC-0.94.zip: JVPC-0.94/jvpc/ShipFrame.java <==
// File: ShipFrame.java

package jvpc.jvpc;

import java.awt.*;
import java.awt.event.*;
import kero.util.*;
import kero.awt.*;
import jvpc.vga.*;

/**
 * Presents a <CODE>Ship</code> in a <CODE>Frame</code>. Does not have
 * <CODE>Container</code> functionality (explicitely dropped).
 *
 * @author    Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since     22 V 1999
 * @version   18 III 2001
 */
public class ShipFrame
    extends MyFrame
    implements VGAPlanets, ShipListener,
	       ItemListener, ActionListener, KeyListener
{
    // fields with information
    Game game;
    Ship ship; // ship from a turn (not a result)

    // fields for UI
    static ShipFrame lastopened;
    JVPC applet;

    // General fields
    Button prev, next;
    InputField name, fcode;
    TextField fcfield;
    Label owner, crew,damage;
    Label hull, engine, torp, beam;
    // Mission stuff (quite a lot, to be PHost compatible)
    Panel missionPanel, targetPanel;      // when editable, use this Panel
    InputChoice missionchoice;            // stuff this all..
    IntInput inttarget,towtarget;     // ..into missionpanel
    InputChoice enemy;
    // Other stuff
    InputChoice warp;
    Label position;
    IntInput newx,newy;
    Panel buttonPanel;
    Button cargo, planet;

    private void setupMissionChoice() {
	missionchoice = new InputChoice("Mission:");
	int m = 0;
	Mission mi;
	String str = game.getMission(m).getName();
	while (str != null) {
	    missionchoice.addSelection(str);
	    m++;
	    mi=game.getMission(m);
	    if (mi != null) str = mi.getName(); else str = null;
	}
	PConfig pconfig = ship.getUniverse().getConfig();
	if (pconfig != null) {
	    // add separator?
	    for (m=pconfig.extMissionsStartAt(); m<=game.getMissVecSize(); m++){
		mi = game.getMission(m);
		if (mi!=null) {
		    str = mi.getName();
		    missionchoice.addSelection(str);
		}
	    }
	}
	missionchoice.addActionListener(this);
    }

    public void itemStateChanged(ItemEvent ie) {
	String str = (String)ie.getItem();
	Object source = ie.getSource();
	if (source instanceof Choice) {
	    //if (source==missionchoice) setMission(game.getMission(str));
	}
    }

    public void actionPerformed(ActionEvent ae) {
	super.actionPerformed(ae);
	// String str = (String)ae.getActionCommand();
	// Object source = ae.getSource();
    }

    public void setShipIntTarget() {
	ship.setIntTarget(inttarget.getInt());
    }

    public void setShipTowTarget() {
	ship.setTowTarget(towtarget.getInt());
    }

    protected String oldName = "";

    public void setMission(Mission mission) {
	String newName = mission.getName();
	missionchoice.setSelection(newName);
	boolean sameMission = oldName.equals(newName);
	oldName = newName;
	if (sameMission) return;

	targetPanel.removeAll();
	addInputTo(missionPanel,missionchoice, KeyEvent.VK_M, "setShipMission");
	// set intercept label+textfield
	String hint = mission.getIntHint();
	if (hint != null) {
	    inttarget.setLabel(hint);
	    inttarget.setInt(ship.getIntTarget());
	    addNumberInputTo(targetPanel, inttarget, KeyEvent.VK_I,
			     "setShipIntTarget");
	}
	// set tow label+textfield
	hint = mission.getTowHint();
	if (hint != null) {
	    towtarget.setLabel(hint);
	    towtarget.setInt(ship.getTowTarget());
	    addNumberInputTo(targetPanel, towtarget, KeyEvent.VK_T,
			     "setShipTowTarget");
	}

	// work-around for kaffe: can not handle empty GridLayout-Containers
	if (targetPanel.getComponentCount() == 0) targetPanel.add(new Label());

	missionPanel.validate();
    }

    public void setShipMission() {
	Mission mission = game.getMission(missionchoice.getSelection());
	ship.setMission(mission.getId());
	//setMission(mission);
    }

    public void setWarp(String warp) {
	String stripped = warp.substring(1,2);
	ship.setWarp(Integer.parseInt(stripped));
    }

    public void setShipEnemy() {
	ship.setEnemy(enemy.getIndex());
    }

    public ShipFrame(Ship sh, JVPC ja) {
	ship = sh;
	game = ship.getUniverse().getGame();
	applet = ja;

	ship.getUniverse().addShipListener(this);

	owner = new Label();
	crew = new Label();
	damage = new Label();
	setLayout(new GridLayout(0,1));

	FlowLayout flowNoVgap = new FlowLayout();
	flowNoVgap.setVgap(0); // v-gap, not vga-p :-)

    Panel f = new Panel(new GridLayout(1, 0));
    prev = new Button("prev");
    addButtonTo(f, prev, KeyEvent.VK_Z, "prevShip");
    next = new Button("neXt");
    addButtonTo(f, next, KeyEvent.VK_X, "nextShip");
	f.add(damage);
	f.add(crew);
	f.add(owner);
    add(f);
    f = new Panel(new GridLayout(1, 0));
	f.add(damage);
	f.add(crew);
	f.add(owner);
    add(f);

	add(hull = new Label());
	add(engine = new Label());
	add(beam = new Label());
	add(torp = new Label());

	name = new InputField("Name:", "");
	// name.setTextFont(new Font("Courier",12,Font.PLAIN));
	addInputField(name, KeyEvent.VK_N, "setShipName");

	fcode = new InputField("Friendly code:", "XXX");
	addInputField(fcode, KeyEvent.VK_F, "setShipFC");

	inttarget = new IntInput("Intercept:", 500, 2, 0);
	towtarget = new IntInput("Tow Ship:", 500, 2, 0);
	setupMissionChoice();

	missionPanel = new Panel(new BorderLayout());
	targetPanel = new Panel(new GridLayout(1, 0));
	missionPanel.add(targetPanel, "East");
	enemy = new InputChoice("primary Enemy:");
	// enemychoice.addItemListener(this);
	for (int i=0; i<=races; i++) enemy.addSelection(game.getLongRace(i));
	warp = new InputChoice("Warp:");
	for (int i=0; i<=maxWarp; i++) warp.addSelection(" "+i+" ");
	addInput(warp, KeyEvent.VK_W, "setShipWarp");
	Panel pos_dest = new Panel(new GridLayout(1, 0));
	Panel dest = new Panel(new GridLayout(1, 0));
	position = new Label();
	pos_dest.add(position);
	newx = new IntInput("dest. X:", 1234, 1, 0);
	newx.addActionListener(this);
	addNumberInputTo(dest, newx, KeyEvent.VK_X, "setDestX");
	newy = new IntInput("Y:", 1243, 1, 0);
	newy.addActionListener(this);
	addNumberInputTo(dest, newy, KeyEvent.VK_Y, "setDestY");
	pos_dest.add(dest);

	// group items
	add(fcode);
	add(missionPanel);
	addInput(enemy, KeyEvent.VK_E, "setShipEnemy");
	add(pos_dest);
	add(warp);

	buttonPanel = new Panel(new GridLayout(1, 0));
	cargo = new Button("carGo");
	addButtonTo(buttonPanel, cargo, KeyEvent.VK_G, "viewCargoFrame");
	planet = new Button("Planet");
	addButtonTo(buttonPanel, planet, KeyEvent.VK_P, "viewPlanetFrame");
	add(buttonPanel);

	setShip(sh);
	pack();
	limitSize();
	show();
	name.requestFocus();
    }

    public void setShip(Ship sh) {
	ship = sh;

	Universe u = ship.getUniverse();
	setTitle("S"+ship.getId()+", "+u.getTurnString());
	owner.setText("Owner: "+ship.getOwner());
	hull.setText(""+ship.getHull().getName());
	engine.setText(""+ship.getHull().getEngines()+" "+ship.getEngine().getName());
	int beamcount = ship.getBeamCount();
	if (beamcount > 0) {
	    beam.setText(""+beamcount+" "+ship.getBeam().getName());
	} else {
	    beam.setText("(no beams)");
	}
	int launchcount = ship.getLaunchCount();
	if (launchcount > 0) {
	    torp.setText(""+launchcount+" "+ship.getTorpedo().getName());
	} else {
	    torp.setText("(no torpedoes)");
	}

	name.setText(ship.getName());
	fcode.setText(ship.getFC());

	setMission(game.getMission(ship.getMission()));
	enemy.setSelection(game.getLongRace(ship.getEnemy()));
	warp.setSelection(ship.getWarp());
	position.setText("Pos: ("+ship.getX()+","+ship.getY()+")");
	newx.setInt(ship.getX()+ship.getDX());
	newy.setInt(ship.getY()+ship.getDY());
	int crewcount = ship.getCrew();
	if (crewcount>0) { // UNKNOWN???
	    int hullcrewcount = ship.getHull().getCrew();
	    if (crewcount < hullcrewcount) {
		crew.setText("Crew: "+crewcount+" (should be "+hullcrewcount+")");
	    } else {
		crew.setText("Crew: "+crewcount);
	    }
	}
	damage.setText("Damage: "+ship.getDamage());

	Planet p = ship.getLocation().getPlanet();
	if (p != null) {
	    buttonPanel.add(planet);
	} else {
	    buttonPanel.remove(planet);
	}
	buttonPanel.validate();
    }


    // KeyListener methods

    public void keyPressed(KeyEvent ke) {
	super.keyPressed(ke);
	boolean altheld = (ke.getModifiers() & KeyEvent.ALT_MASK) != 0;
	boolean ctrlheld = (ke.getModifiers() & KeyEvent.CTRL_MASK) != 0;
	boolean shiftheld = (ke.getModifiers() & KeyEvent.SHIFT_MASK) != 0;

	int keycode = ke.getKeyCode();
	switch (keycode) {
	case KeyEvent.VK_EQUALS:
	    if (!altheld && !ctrlheld) break;
	default:
	    // ignore
	    break;
	}
    }

    public void keyReleased(KeyEvent ke) {
	super.keyReleased(ke);
    }

    public void keyTyped(KeyEvent ke) {
	super.keyTyped(ke);
    }

  public void nextShip() {
    nextShip(true);
  }
  
  public void nextShip(boolean visitAlly) {
    int newid = ship.getId() + 1;
    if (newid > ships) newid = 1;
    while (newid != ship.getId()) {
      Ship newship = ship.getUniverse().getShip(newid);
      if ((newship != null) && newship.isOurShip()) {
	if ((newship.getOwner() == ship.getOwner()) || visitAlly) {
	  break;
	}
      }
      newid++;
      if (newid > ships) newid = 1;
    }
    setShip(ship.getUniverse().getShip(newid));
  }

  public void prevShip() {
    prevShip(true);
  }

  public void prevShip(boolean visitAlly) {
    int newid = ship.getId() - 1;
    if (newid == 0) newid = ships;
    while (newid != ship.getId()) {
      Ship newship = ship.getUniverse().getShip(newid);
      if ((newship != null) && newship.isOurShip()) {
	if ((newship.getOwner() == ship.getOwner()) || visitAlly) {
	  break;
	}
      }
      newid--;
      if (newid == 0) newid = ships;
    }
    setShip(ship.getUniverse().getShip(newid));
  }

    // ShipFrame overridden methods

    public void report(String warning) {
	game.report(warning);
	System.err.println(warning);
    }

    public void shipChanged(ShipEvent se) {
	if (se.getId() == ship.getId()) setShip(ship);
    }


    // methods for setting all ship fields

    public void setShipName() {
	ship.setName(((InputField)name).getText());
    }

    public void setShipFC() {
	ship.setFC(((InputField)fcode).getText());
    }

    public void setDestX() {
	ship.setDX(newx.getInt() - ship.getX());
    }

    public void setDestY() {
	ship.setDY(newy.getInt() - ship.getY());
    }

    public void setShipWarp() {
	ship.setWarp(warp.getIndex());
    }

    public void viewCargoFrame() {
	Location location = ship.getLocation();
	applet.viewCargoFrame(location);
    }

    public void viewPlanetFrame() {
	Planet p = ship.getLocation().getPlanet();
	applet.viewPlanet(p);	
    }
}
